@@ -39,6 +39,10 @@
 #' }
 #' @export
 readSql <- function(sourceFile) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(sourceFile, len = 1, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   readChar(sourceFile, file.info(sourceFile)$size)
 }
 
@@ -60,6 +64,11 @@ readSql <- function(sourceFile) {
 #' }
 #' @export
 writeSql <- function(sql, targetFile) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(sql, len = 1, add = errorMessages)
+  checkmate::assertCharacter(targetFile, len = 1, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   sink(targetFile)
   sql <- gsub(
     "\r",
@@ -99,6 +108,12 @@ writeSql <- function(sql, targetFile) {
 #' }
 #' @export
 renderSqlFile <- function(sourceFile, targetFile, warnOnMissingParameters = TRUE, ...) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(sourceFile, len = 1, add = errorMessages)
+  checkmate::assertCharacter(targetFile, len = 1, add = errorMessages)
+  checkmate::assertLogical(warnOnMissingParameters, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   sql <- readSql(sourceFile)
   sql <- render(sql, warnOnMissingParameters, ...)
   writeSql(sql, targetFile)
@@ -134,6 +149,15 @@ translateSqlFile <- function(sourceFile,
                              targetDialect,
                              tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
                              oracleTempSchema = NULL) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(sourceFile, len = 1, add = errorMessages)
+  checkmate::assertCharacter(targetFile, len = 1, add = errorMessages)
+  checkmate::assertCharacter(targetDialect, len = 1, add = errorMessages)
+  checkmate::assertChoice(targetDialect, listSupportedDialects()$dialect, add = errorMessages)
+  checkmate::assertCharacter(tempEmulationSchema, len = 1, null.ok = TRUE, add = errorMessages)
+  checkmate::assertCharacter(oracleTempSchema, len = 1, null.ok = TRUE, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   if (!is.null(oracleTempSchema) && oracleTempSchema != "") {
     warn("The 'oracleTempSchema' argument is deprecated. Use 'tempEmulationSchema' instead.",
       .frequency = "regularly",
@@ -195,6 +219,16 @@ loadRenderTranslateSql <- function(sqlFilename,
                                    tempEmulationSchema = getOption("sqlRenderTempEmulationSchema"),
                                    oracleTempSchema = NULL,
                                    warnOnMissingParameters = TRUE) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(sqlFilename, len = 1, add = errorMessages)
+  checkmate::assertCharacter(packageName, len = 1, add = errorMessages)
+  checkmate::assertCharacter(dbms, len = 1, add = errorMessages)
+  checkmate::assertChoice(dbms, listSupportedDialects()$dialect, add = errorMessages)
+  checkmate::assertCharacter(tempEmulationSchema, len = 1, null.ok = TRUE, add = errorMessages)
+  checkmate::assertCharacter(oracleTempSchema, len = 1, null.ok = TRUE, add = errorMessages)
+  checkmate::assertLogical(warnOnMissingParameters, len = 1, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   if (!is.null(oracleTempSchema) && oracleTempSchema != "") {
     rlang::warn("The 'oracleTempSchema' argument is deprecated. Use 'tempEmulationSchema' instead.",
       .frequency = "regularly",
@@ -258,6 +292,10 @@ trim <- function(string) {
 #'
 #' @export
 snakeCaseToCamelCase <- function(string) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(string, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   string <- tolower(string)
   for (letter in letters) {
     string <- gsub(paste("_", letter, sep = ""), toupper(letter), string)
@@ -278,6 +316,10 @@ snakeCaseToCamelCase <- function(string) {
 #'
 #' @export
 camelCaseToSnakeCase <- function(string) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(string, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   string <- gsub("([A-Z])", "_\\1", string)
   string <- tolower(string)
   string <- gsub("([a-z])([0-9])", "\\1_\\2", string)
@@ -296,6 +338,10 @@ camelCaseToSnakeCase <- function(string) {
 #'
 #' @export
 camelCaseToTitleCase <- function(string) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(string, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   string <- gsub("([A-Z])", " \\1", string)
   string <- gsub("([a-z])([0-9])", "\\1 \\2", string)
   substr(string, 1, 1) <- toupper(substr(string, 1, 1))
@@ -314,9 +360,13 @@ camelCaseToTitleCase <- function(string) {
 #' @examples
 #' x <- data.frame(concept_id = 1, concept_name = "b")
 #' snakeCaseToCamelCaseNames(x)
-#' 
+#'
 #' @export
 snakeCaseToCamelCaseNames <- function(object) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertNamed(object, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   names(object) <- snakeCaseToCamelCase(names(object))
   return(object)
 }
@@ -331,9 +381,13 @@ snakeCaseToCamelCaseNames <- function(object) {
 #' @examples
 #' x <- data.frame(conceptId = 1, conceptName = "b")
 #' camelCaseToSnakeCaseNames(x)
-#' 
+#'
 #' @export
 camelCaseToSnakeCaseNames <- function(object) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertNamed(object, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   names(object) <- camelCaseToSnakeCase(names(object))
   return(object)
 }
@@ -368,6 +422,13 @@ createRWrapperForSql <- function(sqlFilename,
                                  rFilename,
                                  packageName,
                                  createRoxygenTemplate = TRUE) {
+  errorMessages <- checkmate::makeAssertCollection()
+  checkmate::assertCharacter(sqlFilename, len = 1, add = errorMessages)
+  checkmate::assertCharacter(rFilename, len = 1, add = errorMessages)
+  checkmate::assertCharacter(packageName, len = 1, add = errorMessages)
+  checkmate::assertLogical(createRoxygenTemplate, len = 1, add = errorMessages)
+  checkmate::reportAssertions(collection = errorMessages)
+
   if (missing(rFilename)) {
     periodIndex <- which(strsplit(sqlFilename, "")[[1]] == ".")
     if (length(periodIndex) == 0) {
